%global scm_release Rhino%(v=%{version}; echo ${v//\./_})_Release
%global test262_commit f94fc660cc3c59b1f2f9f122fc4d44b4434b935c
%global test262_shortcommit %(c=%{test262_commit}; echo ${c:0:7})

Name:           rhino
Version:        1.7.14
Release:        %mkrel 3
Group:          Development/Java
Summary:        JavaScript for Java
# rhino itself is MPLv2.0 but use other codes, breakdown:
# BSD: toolsrc/org/mozilla/javascript/tools/debugger/treetable/*
#      src/org/mozilla/javascript/v8dtoa/* except FastDtoaBuilder.java
License:        MPLv2.0 and BSD
URL:            https://mozilla.github.io/rhino
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch
ExcludeArch:    %{ix86}

Source0:        %{url}/archive/%{scm_release}/%{name}-%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/org/mozilla/%{name}/%{version}/%{name}-%{version}.pom
Source2:        https://repo1.maven.org/maven2/org/mozilla/%{name}-engine/%{version}/%{name}-engine-%{version}.pom
Source3:        https://repo1.maven.org/maven2/org/mozilla/%{name}-runtime/%{version}/%{name}-runtime-%{version}.pom
# required for tests
Source4:        https://github.com/tc39/test262/archive/%{test262_shortcommit}/test262-%{test262_shortcommit}.tar.gz

BuildRequires:  maven-local
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.yaml:snakeyaml)
BuildRequires:  mvn(jakarta.xml.soap:jakarta.xml.soap-api)
Requires:       javapackages-tools

%description
Rhino is an open-source implementation of JavaScript written entirely in Java.
It is typically embedded into Java applications to provide scripting to end
users. Full jar including tools, excluding the JSR-223 Script Engine wrapper.

%package -n %{name}-engine
Summary:        Rhino Engine
%description -n %{name}-engine
Rhino Javascript JSR-223 Script Engine wrapper.

%package -n %{name}-runtime
Summary:        Rhino Runtime
%description -n %{name}-runtime
Rhino JavaScript runtime jar, excludes tools & JSR-223 Script Engine wrapper.

%{?javadoc_package}

%prep
%autosetup -p1 -n %{name}-%{scm_release}

# Uncomment to include test262
tar --extract --strip-component=1 --file=%{SOURCE4} --directory=test262

# jar in tests is used by requireJarTest
find -type f '(' -name '*.jar' -o -name '*.class' ')' -not -path './testsrc/*' -print -delete

# requires netscape.security
rm -rf testsrc/tests/src

mkdir %{name}
mkdir %{name}-engine
mkdir %{name}-runtime

# use simplest pom as parent pom
cp %{SOURCE1} pom.xml
cp %{SOURCE1} %{name}/pom.xml
cp %{SOURCE2} %{name}-engine/pom.xml
cp %{SOURCE3} %{name}-runtime/pom.xml

%pom_add_dep junit:junit:4.13.2:test %{name}
%pom_add_dep org.yaml:snakeyaml:1.28:test %{name}
%pom_add_dep jakarta.xml.soap:jakarta.xml.soap-api:1.4.0:test %{name}

# needed by surefire plugin
%pom_add_dep org.apache.commons:commons-lang3:3.8.1:test %{name}
%pom_add_dep commons-io:commons-io:2.6:test %{name}

%pom_xpath_set pom:artifactId %{name}-parent
%pom_xpath_set pom:name %{name}-parent
%pom_xpath_inject pom:project '<packaging>pom</packaging>'

%pom_remove_parent . \
    %{name} \
    %{name}-engine \
    %{name}-runtime

%pom_xpath_inject pom:project '
    <modules>
      <module>%{name}</module>
      <module>%{name}-engine</module>
      <module>%{name}-runtime</module>
    </modules>'

%pom_add_plugin org.codehaus.mojo:build-helper-maven-plugin \
    %{name} '
    <executions>
      <execution>
        <id>add-source</id>
        <goals>
          <goal>add-source</goal>
        </goals>
        <configuration>
          <sources>
            <source>${project.basedir}/../src</source>
            <source>${project.basedir}/../toolsrc</source>
            <source>${project.basedir}/../xmlimplsrc</source>
          </sources>
        </configuration>
      </execution>
      <execution>
        <id>add-test-source</id>
        <goals>
          <goal>add-test-source</goal>
        </goals>
        <configuration>
          <sources>
            <source>${project.basedir}/../examples</source>
            <source>${project.basedir}/../testsrc</source>
          </sources>
        </configuration>
      </execution>
    </executions>'

%pom_xpath_inject pom:project/pom:build '
    <resources>
      <resource>
        <directory>${project.basedir}/../src</directory>
        <excludes>
          <exclude>**/*.java</exclude>
          <exclude>build.xml</exclude>
          <exclude>manifest</exclude>
        </excludes>
      </resource>
      <resource>
        <directory>${project.basedir}/../toolsrc</directory>
        <excludes>
          <exclude>**/*.java</exclude>
          <exclude>build.xml</exclude>
          <exclude>manifest</exclude>
        </excludes>
      </resource>
    </resources>
    <testResources>
      <testResource>
        <directory>${project.basedir}/../testsrc</directory>
        <excludes>
          <exclude>**/*.java</exclude>
        </excludes>
      </testResource>
    </testResources>' \
      %{name}

%pom_add_plugin :maven-surefire-plugin \
    %{name} '
    <configuration>
      <argLine>
        -Xss1280k
        -Dfile.encoding=UTF-8
        --add-opens java.desktop/javax.swing.table=ALL-UNNAMED
      </argLine>
      <excludes>
        <exclude>**/benchmarks/**</exclude>
      </excludes>
      <forkCount>64</forkCount>
      <reuseForks>false</reuseForks>
      <systemPropertyVariables>
        <java.awt.headless>true</java.awt.headless>
        <mozilla.js.tests>testsrc/tests</mozilla.js.tests>
        <mozilla.js.tests.timeout>60000</mozilla.js.tests.timeout>
        <user.language>en</user.language>
        <user.country>US</user.country>
        <user.timezone>America/Los_Angeles</user.timezone>
        <TEST_OPTLEVEL>-1</TEST_OPTLEVEL>
        <TEST_262_OPTLEVEL>-1</TEST_262_OPTLEVEL>
        <test262properties>testsrc/test262.properties</test262properties>
      </systemPropertyVariables>
      <workingDirectory>${project.basedir}/../</workingDirectory>
    </configuration>'

%pom_add_plugin :maven-resources-plugin \
    %{name}-engine \
    %{name}-runtime '
    <executions>
      <execution>
        <id>copy-resources</id>
        <phase>generate-sources</phase>
        <goals>
          <goal>copy-resources</goal>
        </goals>
        <configuration>
          <outputDirectory>${project.build.outputDirectory}</outputDirectory>
          <resources>
            <resource>
              <directory>${project.basedir}/../%{name}/target/classes</directory>
            </resource>
          </resources>
        </configuration>
      </execution>
    </executions>'

%pom_add_plugin :maven-jar-plugin \
    %{name} '
    <configuration>
      <archive>
        <manifestEntries>
          <Main-Class>org.mozilla.javascript.tools.shell.Main</Main-Class>
          <Implementation-Title>Mozilla Rhino</Implementation-Title>
          <Implementation-Version>${project.version}</Implementation-Version>
          <Automatic-Module-Name>org.mozilla.rhino</Automatic-Module-Name>
          <Bundle-SymbolicName>org.mozilla.rhino</Bundle-SymbolicName>
        </manifestEntries>
      </archive>
      <excludes>
        <exclude>META-INF/services/**</exclude>
        <exclude>org/mozilla/javascript/engine/**</exclude>
      </excludes>
    </configuration>'

%pom_add_plugin :maven-jar-plugin \
    %{name}-engine '
    <configuration>
      <archive>
        <manifestEntries>
          <Automatic-Module-Name>org.mozilla.rhino.engine</Automatic-Module-Name>
        </manifestEntries>
      </archive>
      <includes>
        <include>META-INF/services/**</include>
        <include>org/mozilla/javascript/engine/**</include>
      </includes>
    </configuration>'

%pom_add_plugin :maven-jar-plugin \
    %{name}-runtime '
    <configuration>
      <archive>
        <manifestEntries>
          <Bundle-SymbolicName>org.mozilla.rhino-runtime</Bundle-SymbolicName>
        </manifestEntries>
      </archive>
      <excludes>
        <exclude>META-INF/services/**</exclude>
        <exclude>org/mozilla/javascript/engine/**</exclude>
        <exclude>org/mozilla/javascript/tools/**</exclude>
      </excludes>
    </configuration>'

%mvn_package :%{name}-parent \
    __noinstall

# Compatibility
%mvn_alias :%{name} rhino:js
%mvn_file :%{name} rhino/%{name} %{name}

%build
# Ignore test
%mvn_build -f -s -- -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%jpackage_script org.mozilla.javascript.tools.shell.Main "" "" rhino rhino true
%jpackage_script org.mozilla.javascript.tools.debugger.Main "" "" rhino rhino-debugger true
%jpackage_script org.mozilla.javascript.tools.jsc.Main "" "" rhino rhino-jsc true

mkdir -p %{buildroot}%{_mandir}/man1/
install -m 644 man/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%files -n %{name} -f .mfiles-%{name}
%{_bindir}/%{name}
%{_bindir}/%{name}-debugger
%{_bindir}/%{name}-jsc
%{_mandir}/man1/%{name}.1*
%license LICENSE.txt NOTICE.txt NOTICE-tools.txt
%doc README.md CODE_OF_CONDUCT.md RELEASE-NOTES.md

%files -n %{name}-engine -f .mfiles-%{name}-engine
%license LICENSE.txt
%doc README.md CODE_OF_CONDUCT.md RELEASE-NOTES.md

%files -n %{name}-runtime -f .mfiles-%{name}-runtime
%license LICENSE.txt NOTICE.txt
%doc README.md CODE_OF_CONDUCT.md RELEASE-NOTES.md



%changelog
* Sun Jun 29 2025 umeabot <umeabot> 1.7.14-3.mga10
+ Revision: 2223895
- Mageia 10 Mass Rebuild

* Mon May 27 2024 ns80 <ns80> 1.7.14-2.mga10
+ Revision: 2068173
- rebuild for java 21

* Wed Dec 14 2022 daviddavid <daviddavid> 1.7.14-1.mga9
+ Revision: 1921934
- Update to 1.7.14 (#2024769)
- Change package url
- Add new test deps: mvn(jakarta.xml.soap:jakarta.xml.soap-api)
- Write new description and summary
- Remove POM properties (it's not used anymore)
- Add Automatic-Module-Name and Bundle-SymbolicName to manifest attributes
- Add different license for each subpackage

* Wed Sep 21 2022 neoclust <neoclust> 1.7.7.1-8.mga9
+ Revision: 1891179
- Fix build with jdk 17
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Mar 01 2021 daviddavid <daviddavid> 1.7.7.1-6.mga9
+ Revision: 1694921
- Change jline dep to jline2 and jansi dep to jansi1
+ danf <danf>
- Switch URLs from http: to https:

* Wed Feb 12 2020 umeabot <umeabot> 1.7.7.1-5.mga8
+ Revision: 1507602
- Mageia 8 Mass Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 1.7.7.1-4.mga7
+ Revision: 1290767
- Mageia 7 Mass Rebuild

* Mon Oct 02 2017 daviddavid <daviddavid> 1.7.7.1-3.mga7
+ Revision: 1162580
- Update to version 1.7.7.1 (sync with fc27)
- Add BR javapackages-local to unbreak build
- Install JAR and POM with %%mvn_install
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1.7.7-3.mga6
+ Revision: 978143
- First rebuild of the java stack
- sync package rhino with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Jan 13 2015 daviddavid <daviddavid> 1.7R4-5.mga5
+ Revision: 810561
- Sync with fc21
- fix Group

* Wed Oct 15 2014 umeabot <umeabot> 1.7R4-4.mga5
+ Revision: 741855
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.7R4-3.mga5
+ Revision: 688669
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 1.7R4-2.mga4
+ Revision: 542312
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 dmorgan <dmorgan> 1.7R4-1.mga4
+ Revision: 497352
- New version

* Mon Jan 14 2013 umeabot <umeabot> 1.7R3-8.mga3
+ Revision: 380334
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 16 2012 dmorgan <dmorgan> 1.7R3-7.mga3
+ Revision: 331594
- New version

* Mon Jan 16 2012 dmorgan <dmorgan> 0:1.7-1.mga2
+ Revision: 196682
- Migrate to new maven macros
- Remove gcj support

* Mon Sep 12 2011 gil <gil> 0:1.7-0.0.7.mga2
+ Revision: 142780
- added m2 pom2
+ pterjan <pterjan>
- imported package rhino


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.7-0.0.6mdv2011.0
+ Revision: 607365
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.7-0.0.5mdv2010.1
+ Revision: 523921
- rebuilt for 2010.1

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:1.7-0.0.4mdv2010.0
+ Revision: 426914
- rebuild

* Sat Mar 07 2009 Antoine Ginies <aginies@mandriva.com> 0:1.7-0.0.3mdv2009.1
+ Revision: 351560
- rebuild

* Wed Jun 18 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.7-0.0.2mdv2009.0
+ Revision: 225399
- switch to the 1.7 release, disable gcj_compile

* Sat Jan 12 2008 David Walluck <walluck@mandriva.org> 0:1.7-0.0.1mdv2008.1
+ Revision: 149258
- 1_7R1-RC1

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:1.6-0.r5.5mdv2008.1
+ Revision: 120815
- buildrequires java-rpmbuild

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.6-0.r5.4mdv2008.0
+ Revision: 87352
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Sat Sep 08 2007 Pascal Terjan <pterjan@mandriva.org> 0:1.6-0.r5.3mdv2008.0
+ Revision: 82690
- update to new version


* Mon Mar 12 2007 David Walluck <walluck@mandriva.org> 0:1.6-0.r5.2mdv2007.1
+ Revision: 141810
- fix gcj_support
- spec cleanup

* Mon Dec 11 2006 David Walluck <walluck@mandriva.org> 0:1.6-0.r5.1mdv2007.1
+ Revision: 95055
- 1.6.0R5
  fix eol for javadoc
- Import rhino

* Thu Jun 15 2006 David Walluck <walluck@mandriva.org> 0:1.6-0.r2.2.1mdv2007.0
- bunmp release
- still no E4X implementation (xmlbeans) or bea-stax-api

* Fri Jun 02 2006 David Walluck <walluck@mandriva.org> 0:1.6-0.r2.1.1mdv2007.0
- release

* Thu Jun 01 2006 Fernando Nasser <fnasser@redhat.com> 0:1.6-0.r2.1jpp
- Upgrade to RC2

* Tue Apr 25 2006 Fernando Nasser <fnasser@redhat.com> 0:1.6-0.r1.2jpp
- First JPP 1.7 build

* Thu Dec 02 2004 David Walluck <david@jpackage.org> 0:1.6-0.r1.1jpp
- 1_6R1
- add demo subpackage containing example code
- add jpp release info to implementation version
- add script to launch js shell
- build E4X implementation (Requires: xmlbeans)
- remove `Class-Path' from manifest

* Wed Aug 25 2004 Fernando Nasser <fnasser@redhat.com> - 0:1.5-1.R5.1jpp
- Update to 1.5R5.
- Rebuild with Ant 1.6.2

